pywws — pywws 13.06_r1023 documentation

### Navigation

- index
- modules |
- suivant |
- pywws 13.06_r1023 documentation »

# pywws

Logiciel Python pour Station météo USB sans-fil
http://pythonhosted.org/pywws
http://jim-easterbrook.github.com/pywws/
http://github.com/jim-easterbrook/pywws/

Ce document est disponible dans les langues suivantes (Les versions autres que anglais peuvent ne pas être complètes ou à jour):

> - English
> - Français

## Introduction

pywws est une collection de scripts Python pour lire, stocker et traiter les données des stations météorologiques sans fil USB courantes tels que Elecsa AstroTouch 6975, Watson W-8681, WH-1080PC, WH1080, WH1081, WH3080 etc Je suppose que tout modèle de station fourni avec le logiciel EasyWeather pour Windows est compatible, mais ne peut pas le garantir.

Le logiciel a été développé pour fonctionner dans environnement de faible puissance, avec peu de mémoire tel un routeur. Il peut être utilisé pour créer des graphiques et des pages Web affichant de récentes lectures météorologiques, généralement mis à jour à chaque heure. Il peut également envoyer des données à des services tels que: Weather Underground http://www.wunderground.com/ et poster des messages sur Twitter.

J’ai écrit ce logiciel pour répondre à mes besoins, mais ai essayé de le rendre adaptable aux besoins des autres. Vous voudrez peut-être modifier certains ou tous les modules, ou en écrire de nouveaux, pour lui faire faire exactement ce que vous souhaitez. L’une des raisons pour lesquelles Python est utilisé est qu’il rend de telles modifications si facile. N’ayez pas peur, essayez-le vous verrez..

## Exigences

Les logiciels que vous aurez besoin pour exécuter pywws dépend de ce que vous comptez en faire. En particulier, le choix de bibliothèque USB, en fonction de ce qui est disponible sur les différents systèmes d’exploitation.

> - Python version 2.5 ou ultérieure (note: Le support de Python v3 est en cours de développement - certaines choses peuvent ne pas fonctionner correctement)
> - USB library option 1 (preferred, except on MacOS):
>   - PyUSB version 1.0
>   - libusb version 0.1 ou version 1.0
> - USB library option 2 (if PyUSB 1.0 is not available):
>   - PyUSB version 0.4
>   - libusb version 0.1
> - Librarie USB - option 3 (préférable pour les Mac):
>   - hidapi
>   - ctypes
> - USB library option 4:
>   - hidapi
>   - cython-hidapi
>   - cython
> - Pour le tracé des graphes
>   - gnuplot v4.2 ou ultérieur
> - Pour téléversement sécurisé sur votre site web (sftp)
>   - paramiko
>   - pycrypto
> - Pour les mises à jour Twitter
>   - tweepy v2.0 or higher
>   - simplejson
> - Pour créer de nouvelles traductions
>   - gettext
> - Pour ‘compiler’ la documentation
>   - sphinx

## Obtenir une copie de pywws

The simplest way to obtain pywws is to use `pip` to install it directly from the Python Package Index (PyPI). Note that this will probably require ‘root’ privileges, so will need to be run using `sudo`:

    sudo pip install pywws

If you don’t have root privileges, or don’t want to install pywws, you can download a zip or tar.gz file from PyPI and then extract the files into a convenient directory on your computer.

The PyPI files contain a snapshot release of the software - a new one is issued every few months. If you’d like to keep up to date with latest developments of pywws, you should use `git` to clone the pywws repository:

    git clone https://github.com/jim-easterbrook/pywws.git

After doing so you can compile the documentation and language localisation files (which will require the `sphinx` and `gettext` dependencies):

    cd pywws
    python setup.py build_sphinx
    python setup.py msgfmt

For more details, see Comment démarrer avec pywws.

### Upgrading pywws

The method used to upgrade pywws depends on how you originally obtained it. If you downloaded a zip or tar.gz file, you just need to do the same again, with the new version, then delete your old download when you’ve finished setting up the new one. (Note that upgrading is much easier if you do not keep your templates, user modules and weather data in the same directory as the downloaded files.) If you used `pip` you just need to repeat the command. `git` users just need to do a `git pull` command.

Some new versions of pywws have changed what’s stored in the hourly, daily or monthly summary data files. These new versions are incompatible with processed data from earlier versions. The `pywws.Reprocess` module regenerates all the summary data. It should be run after any major upgrade.

## Documentation

Documentation is included with pywws downloads, and is also available online. A good starting place is Comment démarrer avec pywws which describes in more detail how to install pywws.

If you have questions not answered in the documentation, please join the pywws Google mailing list / discussion group and ask there. Note that your first message to the group will not appear immediately – new posters have to be approved by a moderator, to prevent spam messages.

### Contentu

- Licence
- Change log
- User guides
  - Comment démarrer avec pywws
  - Comment configurer la journalisation horaire avec pywws
  - Comment configurer le mode ‘live’ avec pywws
  - How to integrate pywws with various weather services
  - Comment configurer pywws pour poster des messages sur Twitter
  - Comment utiliser pywws dans une autre langue
  - weather.ini - format du fichier de configuration
  - status.ini - status file format
  - Humidity Index (Humidex)
- Python modules
  - Hourly
  - LiveLog
  - Reprocess
  - TwitterAuth
  - SetWeatherStation
  - TestWeatherStation
  - USBQualityTest
  - EWtoPy
  - pywws.Tasks
  - pywws.LogData
  - pywws.Process
  - pywws.calib
  - pywws.Plot
  - pywws.WindRose
  - pywws.Template
  - pywws.Forecast
  - pywws.ZambrettiCore
  - pywws.Upload
  - pywws.ToTwitter
  - pywws.toservice
  - pywws.YoWindow
  - pywws.WeatherStation
  - pywws.device_ctypes_hidapi
  - pywws.device_cython_hidapi
  - pywws.device_pyusb1
  - pywws.device_pyusb
  - pywws.DataStore
  - pywws.TimeZone
  - pywws.Localisation
  - pywws.calib
  - pywws.conversions
  - pywws.Logger

### Indexes et tables

- Index
- Index du module
- Page de recherche

## Crédits

Je n’aurais pas été en mesure d’obtenir d’informations de la station météorologique sans accès aux sources du programme “wwsr” de Michael Pendec . Je suis également redevable à Dave Wells pour le décodage du “bloc fixe” de données de la station météorologique.

En dernier lieu, un grand vous remercie à tous les utilisateurs de pywws qui ont aidé avec leur questions et suggestions, et particulièrement à ceux qui ont traduit pywws et sa documentation en d’autres langues.

## Termes

pywws - Logiciel Python pour stations météo USB sans-fil.
http://github.com/jim-easterbrook/pywws
Copyright (C) 2008-13 Jim Easterbrook jim@jim-easterbrook.me.uk

Ce programme est un logiciel libre, vous pouvez le redistribuer et/ou le modifier selon les termes de la Licence Publique Générale GNU telle que publiée par la Free Software Foundation, soit la version 2 de la Licence, ou (à votre choix) toute version ultérieure.

Ce programme est distribué dans l’espoir qu’il sera utile, mais SANS AUCUNE GARANTIE, sans même la garantie implicite de COMMERCIALISATION ou D’ADAPTATION A UN USAGE PARTICULIER. Voir la licence GNU General Public pour plus de détails.

Vous devriez avoir reçu une copie de la licence GNU General Public License avec ce programme, sinon, écrivez à Free Software Foundation, Inc, 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA

### Navigation

- index
- modules |
- suivant |
- pywws 13.06_r1023 documentation »